@@ -1,7 +1,14 @@
-from cognite.client.data_classes._base import *
+from typing import Any, Dict, List
+
+from cognite.client.data_classes._base import (
+    CogniteFilter,
+    CognitePrimitiveUpdate,
+    CogniteResource,
+    CogniteResourceList,
+    CogniteUpdate,
+)
 
 
-# GenClass: annotationResponse, annotation
 class Annotation(CogniteResource):
     """Representation of an annotation in CDF.
 
@@ -58,20 +65,60 @@ class Annotation(CogniteResource):
         self.data = data
         self.created_time = created_time
         self.last_updated_time = last_updated_time
-        self.cognite_client = cognite_client
-
-
-# GenStop
+        self._cognite_client = cognite_client
 
 
 class AnnotationFilter(CogniteFilter):
-    def __init__(self, annotation_type: str = None, annotated_resource_ids: list = None):
-        self.annotation_type = annotation_type
+    def __init__(
+        self,
+        annotated_resource_type: str,
+        annotated_resource_ids: List[Dict] = None,
+        linked_resource_type: str = None,
+        linked_resource_ids: List[Dict] = None,
+        annotation_type: str = None,
+        text: str = None,
+        status: str = None,
+        source: str = None,
+    ):
+        self.annotated_resource_type = annotated_resource_type
         self.annotated_resource_ids = annotated_resource_ids
+        self.linked_resource_type = linked_resource_type
+        self.linked_resource_ids = linked_resource_ids
+        self.annotation_type = annotation_type
+        self.text = text
+        self.status = status
+        self.source = source
 
 
 class AnnotationUpdate(CogniteUpdate):
-    pass
+    """Changes applied to annotation
+
+    Args:
+        id (int): A server-generated ID for the object.
+    """
+
+    def __init__(self, id: int):
+        super().__init__(id=id)
+
+    class _PrimitiveAnnotationUpdate(CognitePrimitiveUpdate):
+        def set(self, value: Any) -> "AnnotationUpdate":
+            return self._set(value)
+
+    @property
+    def text(self):
+        return AnnotationUpdate._PrimitiveAnnotationUpdate(self, "text")
+
+    @property
+    def status(self):
+        return AnnotationUpdate._PrimitiveAnnotationUpdate(self, "status")
+
+    @property
+    def region(self):
+        return AnnotationUpdate._PrimitiveAnnotationUpdate(self, "region")
+
+    @property
+    def data(self):
+        return AnnotationUpdate._PrimitiveAnnotationUpdate(self, "data")
 
 
 class AnnotationList(CogniteResourceList):
