@@ -1,6 +1,7 @@
 import copy
 from collections import UserList
-from typing import Any, Dict, Iterable, List, Optional, Tuple, Union
+from enum import Enum
+from typing import Any, Dict, List, Optional, Union
 
 import pandas as pd
 from cognite.client.data_classes import ContextualizationJob
@@ -16,6 +17,10 @@ from cognite.experimental.data_classes.utils.pandas import dataframe_summarize
 from cognite.experimental.data_classes.utils.rules_output import _color_matches, _label_groups
 
 
+class ContextualizationJobType(Enum):
+    PNID_PARSER = "pnid_parsing"
+
+
 class EntityMatchingMatchRule(CogniteResource):
     def __init__(
         self,
@@ -465,6 +470,8 @@ class PNIDDetectionPageList(UserList):
 
 
 class PNIDConvertResults(ContextualizationJob):
+    _JOB_TYPE = ContextualizationJobType.PNID_PARSER
+
     @property
     def image(self):
         """Returns the result as an SVG image for output in jupyter"""
@@ -474,6 +481,8 @@ class PNIDConvertResults(ContextualizationJob):
 
 
 class PNIDDetectResults(ContextualizationJob):
+    _JOB_TYPE = ContextualizationJobType.PNID_PARSER
+
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
 
@@ -552,6 +561,12 @@ class DiagramConvertItem(CogniteResource):
 
 
 class DiagramConvertResults(ContextualizationJob):
+    _JOB_TYPE = ContextualizationJobType.PNID_PARSER
+
+    def __init__(self, **kwargs):
+        super().__init__(**kwargs)
+        self._items = None
+
     def __getitem__(self, find_id) -> DiagramConvertItem:
         """retrieves the results for the file with (external) id"""
         found = [
@@ -566,9 +581,17 @@ class DiagramConvertResults(ContextualizationJob):
         return DiagramConvertItem._load(found[0], cognite_client=self._cognite_client)
 
     @property
-    def items(self) -> List[DiagramConvertItem]:
+    def items(self) -> Optional[List[DiagramConvertItem]]:
         """returns a list of all results by file"""
-        return [DiagramConvertItem._load(item, cognite_client=self._cognite_client) for item in self.result["items"]]
+        if self.status == "Completed":
+            self._items = [
+                DiagramConvertItem._load(item, cognite_client=self._cognite_client) for item in self.result["items"]
+            ]
+        return self._items
+
+    @items.setter
+    def items(self, items) -> List[DiagramConvertItem]:
+        self._items = items
 
 
 class DiagramDetectItem(CogniteResource):
@@ -586,6 +609,12 @@ class DiagramDetectItem(CogniteResource):
 
 
 class DiagramDetectResults(ContextualizationJob):
+    _JOB_TYPE = ContextualizationJobType.PNID_PARSER
+
+    def __init__(self, **kwargs):
+        super().__init__(**kwargs)
+        self._items = None
+
     def __getitem__(self, find_id) -> DiagramDetectItem:
         """retrieves the results for the file with (external) id"""
         found = [
@@ -600,9 +629,17 @@ class DiagramDetectResults(ContextualizationJob):
         return DiagramDetectItem._load(found[0], cognite_client=self._cognite_client)
 
     @property
-    def items(self) -> List[DiagramDetectItem]:
+    def items(self) -> Optional[List[DiagramDetectItem]]:
         """returns a list of all results by file"""
-        return [DiagramDetectItem._load(item, cognite_client=self._cognite_client) for item in self.result["items"]]
+        if self.status == "Completed":
+            self._items = [
+                DiagramDetectItem._load(item, cognite_client=self._cognite_client) for item in self.result["items"]
+            ]
+        return self._items
+
+    @items.setter
+    def items(self, items) -> List[DiagramDetectItem]:
+        self._items = items
 
     @property
     def errors(self) -> List[str]:
